# Generated by Django 3.2.2 on 2021-05-10 12:44

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='FileBrowserFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file_type', models.CharField(choices=[('img', 'Изображение'), ('doc', 'Документ')], max_length=3)),
                ('uploaded_file', models.FileField(upload_to='tinymce_filebrowser/%Y/%m/%d', verbose_name='File / Image')),
                ('create_date', models.DateTimeField(auto_now_add=True, verbose_name='Create date')),
            ],
        ),
    ]
